==> ixnetwork_restpy-1.1.4.tar.gz: ixnetwork_restpy-1.1.4/ixnetwork_restpy/testplatform/sessions/ixnetwork/reporter/reporter.py <==
# MIT LICENSE
#
# Copyright 1997 - 2020 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE. 
import sys
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files
if sys.version_info >= (3, 5):
    from typing import List, Any, Union


class Reporter(Base):
    """IxReporter helps to customize a test result report using different options, commands and wizards.
    The Reporter class encapsulates a required reporter resource which will be retrieved from the server every time the property is accessed.
    """

    __slots__ = ()
    _SDM_NAME = 'reporter'
    _SDM_ATT_MAP = {
        'State': 'state',
    }
    _SDM_ENUM_MAP = {
        'state': ['none', 'started', 'stopped'],
    }

    def __init__(self, parent, list_op=False):
        super(Reporter, self).__init__(parent, list_op)

    @property
    def Generate(self):
        """
        Returns
        -------
        - obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.reporter.generate.generate.Generate): An instance of the Generate class

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        from ixnetwork_restpy.testplatform.sessions.ixnetwork.reporter.generate.generate import Generate
        if len(self._object_properties) > 0:
            if self._properties.get('Generate', None) is not None:
                return self._properties.get('Generate')
        return Generate(self)._select()

    @property
    def SaveResults(self):
        """
        Returns
        -------
        - obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.reporter.saveresults.saveresults.SaveResults): An instance of the SaveResults class

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        from ixnetwork_restpy.testplatform.sessions.ixnetwork.reporter.saveresults.saveresults import SaveResults
        if len(self._object_properties) > 0:
            if self._properties.get('SaveResults', None) is not None:
                return self._properties.get('SaveResults')
        return SaveResults(self)._select()

    @property
    def TestParameters(self):
        """
        Returns
        -------
        - obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.reporter.testparameters.testparameters.TestParameters): An instance of the TestParameters class

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        from ixnetwork_restpy.testplatform.sessions.ixnetwork.reporter.testparameters.testparameters import TestParameters
        if len(self._object_properties) > 0:
            if self._properties.get('TestParameters', None) is not None:
                return self._properties.get('TestParameters')
        return TestParameters(self)._select()

    @property
    def State(self):
        # type: () -> str
        """
        Returns
        -------
        - str(none | started | stopped): The state of the current test.
        """
        return self._get_attribute(self._SDM_ATT_MAP['State'])

    def find(self, State=None):
        # type: (str) -> Reporter
        """Finds and retrieves reporter resources from the server.

        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve reporter resources from the server.
        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
        By default the find method takes no parameters and will retrieve all reporter resources from the server.

        Args
        ----
        - State (str(none | started | stopped)): The state of the current test.

        Returns
        -------
        - self: This instance with matching reporter resources retrieved from the server available through an iterator or index

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))

    def read(self, href):
        """Retrieves a single instance of reporter data from the server.

        Args
        ----
        - href (str): An href to the instance to be retrieved

        Returns
        -------
        - self: This instance with the reporter resources from the server available through an iterator or index

        Raises
        ------
        - NotFoundError: The requested resource does not exist on the server
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._read(href)

==> ixnetwork_restpy-1.1.5.tar.gz: ixnetwork_restpy-1.1.5/ixnetwork_restpy/testplatform/sessions/ixnetwork/reporter/reporter.py <==
# MIT LICENSE
#
# Copyright 1997 - 2020 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
import sys
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files

if sys.version_info >= (3, 5):
    from typing import List, Any, Union


class Reporter(Base):
    """IxReporter helps to customize a test result report using different options, commands and wizards.
    The Reporter class encapsulates a required reporter resource which will be retrieved from the server every time the property is accessed.
    """

    __slots__ = ()
    _SDM_NAME = "reporter"
    _SDM_ATT_MAP = {
        "State": "state",
    }
    _SDM_ENUM_MAP = {
        "state": ["none", "started", "stopped"],
    }

    def __init__(self, parent, list_op=False):
        super(Reporter, self).__init__(parent, list_op)

    @property
    def Generate(self):
        """
        Returns
        -------
        - obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.reporter.generate.generate.Generate): An instance of the Generate class

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        from ixnetwork_restpy.testplatform.sessions.ixnetwork.reporter.generate.generate import (
            Generate,
        )

        if len(self._object_properties) > 0:
            if self._properties.get("Generate", None) is not None:
                return self._properties.get("Generate")
        return Generate(self)._select()

    @property
    def SaveResults(self):
        """
        Returns
        -------
        - obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.reporter.saveresults.saveresults.SaveResults): An instance of the SaveResults class

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        from ixnetwork_restpy.testplatform.sessions.ixnetwork.reporter.saveresults.saveresults import (
            SaveResults,
        )

        if len(self._object_properties) > 0:
            if self._properties.get("SaveResults", None) is not None:
                return self._properties.get("SaveResults")
        return SaveResults(self)._select()

    @property
    def TestParameters(self):
        """
        Returns
        -------
        - obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.reporter.testparameters.testparameters.TestParameters): An instance of the TestParameters class

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        from ixnetwork_restpy.testplatform.sessions.ixnetwork.reporter.testparameters.testparameters import (
            TestParameters,
        )

        if len(self._object_properties) > 0:
            if self._properties.get("TestParameters", None) is not None:
                return self._properties.get("TestParameters")
        return TestParameters(self)._select()

    @property
    def State(self):
        # type: () -> str
        """
        Returns
        -------
        - str(none | started | stopped): The state of the current test.
        """
        return self._get_attribute(self._SDM_ATT_MAP["State"])

    def find(self, State=None):
        # type: (str) -> Reporter
        """Finds and retrieves reporter resources from the server.

        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve reporter resources from the server.
        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
        By default the find method takes no parameters and will retrieve all reporter resources from the server.

        Args
        ----
        - State (str(none | started | stopped)): The state of the current test.

        Returns
        -------
        - self: This instance with matching reporter resources retrieved from the server available through an iterator or index

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))

    def read(self, href):
        """Retrieves a single instance of reporter data from the server.

        Args
        ----
        - href (str): An href to the instance to be retrieved

        Returns
        -------
        - self: This instance with the reporter resources from the server available through an iterator or index

        Raises
        ------
        - NotFoundError: The requested resource does not exist on the server
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._read(href)
